@@ -30,6 +30,9 @@ describe 'tripleo::profile::base::database::mysql::client' do
 
       it {
         is_expected.to contain_exec('directory-create-etc-my.cnf.d')
+        is_expected.to contain_file('/etc/my.cnf.d/tripleo.cnf').with(
+          :ensure => 'file',
+        )
         is_expected.to contain_augeas('tripleo-mysql-client-conf').with(
           :incl    => '/etc/my.cnf.d/tripleo.cnf',
           :changes => [
@@ -63,6 +66,28 @@ describe 'tripleo::profile::base::database::mysql::client' do
       }
     end
 
+    context 'with defaults with deployment_type' do
+      let (:params) do
+        { :step => 1 }
+      end
+
+      before (:each) do
+        facts.merge!({ :uuid => 'notdocker', :deployment_type => 'containers' })
+      end
+
+      it {
+        is_expected.to contain_file('/etc/my.cnf.d').with(:ensure => 'directory')
+        is_expected.to contain_augeas('tripleo-mysql-client-conf').with(
+          :incl    => '/etc/my.cnf.d/tripleo.cnf',
+          :changes => [
+            'rm tripleo/bind-address',
+            'rm tripleo/ssl',
+            'rm tripleo/ssl-ca'
+          ]
+        )
+      }
+    end
+
     context 'with ip address set to "" LP#1748180' do
       let (:params) do
         { :step => 1,
